import unittest
from topsis.topsis import topsis

class TestTopsis(unittest.TestCase):
    def test_topsis(self):
        data = [[250, 16, 12, 5],
                [200, 16, 8, 3],
                [300, 32, 16, 4],
                [275, 32, 8, 4],
                [225, 16, 16, 2]]
        weights = [0.25, 0.25, 0.25, 0.25]
        impacts = ['+', '+', '-', '+']
        rankings, _ = topsis(data, weights, impacts)
        self.assertEqual(rankings.tolist(), [3, 1, 4, 2, 5])

if __name__ == '__main__':
    unittest.main()



from setuptools import setup, find_packages

setup(
    name="102203162-topsis",
    version="0.2.0",
    author="Raghav Manchanda",
    author_email="rmanchanda_be22@thapar.edu",
    description="A Python library for the TOPSIS decision-making method.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/yourusername/102203162-topsis",
    packages=find_packages(),
    install_requires=[
        "numpy",
    ],
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)
